@@ -23,12 +23,14 @@ app_ = app.app
 #
 # from fastapi import FastAPI, Form, Depends, File, UploadFile, Body, Request, Path
 #
-#
-# def f(**kwargs):
+# def proxy_app_(kwargs: dict):
 #     logger.info(kwargs)
+#     print(kwargs)
+#     r = requests.request(**kwargs)
+#     return r.json()
 #
 #
-# app.add_route('/p/{a}', f, method="GET", result_key="GetResult")
-#
-# if __name__ == '__main__':
-#     app.run(app.app_from(__file__), port=9955, debug=True)
+# app.add_route_plus(proxy_app_, methods=["GET", "POST"], data=None)
+
+if __name__ == '__main__':
+    app.run(app.app_from(__file__), port=9955, debug=True)
